@@ -62,7 +62,8 @@ keys for help command and doc generation.
 """
 cmd_dict = {'cp': {'options': {'nargs': 2},
                    'params': ['dryrun', 'quiet', 'recursive',
-                              'include', 'exclude', 'acl']},
+                              'include', 'exclude', 'acl',
+                              'no-guess-mime-type']},
             'mv': {'options': {'nargs': 2},
                    'params': ['dryrun', 'quiet', 'recursive',
                               'include', 'exclude', 'acl']},
@@ -71,7 +72,8 @@ cmd_dict = {'cp': {'options': {'nargs': 2},
                               'include', 'exclude']},
             'sync': {'options': {'nargs': 2},
                      'params': ['dryrun', 'delete', 'exclude',
-                                'include', 'quiet', 'acl']},
+                                'include', 'quiet', 'acl',
+                                'no-guess-mime-type']},
             'ls': {'options': {'nargs': '?', 'default': 's3://'},
                    'params': [], 'default': 's3://'},
             'mb': {'options': {'nargs': 1}, 'params': []},
@@ -91,6 +93,9 @@ params_dict = {'dryrun': {'options': {'action': 'store_true'}},
                'delete': {'options': {'action': 'store_true'}},
                'quiet': {'options': {'action': 'store_true'}},
                'force': {'options': {'action': 'store_true'}},
+               'no-guess-mime-type': {'options': {'action': 'store_false',
+                                                  'dest': 'guess_mime_type',
+                                                  'default': True}},
                'recursive': {'options': {'action': 'store_true',
                                          'dest': 'dir_op'}},
                'exclude': {'options': {'action': AppendFilter, 'nargs': 1,
